# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListPublicZonesRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'limit': 'int',
        'marker': 'str',
        'offset': 'int',
        'tags': 'str',
        'name': 'str',
        'id': 'str',
        'status': 'str',
        'search_mode': 'str',
        'sort_key': 'str',
        'sort_dir': 'str',
        'enterprise_project_id': 'str'
    }

    attribute_map = {
        'type': 'type',
        'limit': 'limit',
        'marker': 'marker',
        'offset': 'offset',
        'tags': 'tags',
        'name': 'name',
        'id': 'id',
        'status': 'status',
        'search_mode': 'search_mode',
        'sort_key': 'sort_key',
        'sort_dir': 'sort_dir',
        'enterprise_project_id': 'enterprise_project_id'
    }

    def __init__(self, type=None, limit=None, marker=None, offset=None, tags=None, name=None, id=None, status=None, search_mode=None, sort_key=None, sort_dir=None, enterprise_project_id=None):
        """ListPublicZonesRequest

        The model defined in huaweicloud sdk

        :param type: 待查询的zone的类型。  取值范围：public 默认值为空。
        :type type: str
        :param limit: 每页返回的资源个数。  取值范围：0~500  取值一般为10，20，50。默认值为500。
        :type limit: int
        :param marker: 分页查询起始的资源ID，为空时为查询第一页。  默认值为空。
        :type marker: str
        :param offset: 分页查询起始偏移量，表示从偏移量的下一个资源开始查询。  取值范围：0~2147483647  默认值为0。  当前设置marker不为空时，以marker为分页起始标识。
        :type offset: int
        :param tags: 资源标签。  取值格式：key1,value1|key2,value2  多个标签之间用\&quot;|\&quot;分开，每个标签的键值用英文逗号\&quot;,\&quot;相隔。  多个标签之间为“与”的关系。  关于资源标签，请参见添加资源标签。  搜索模式为精确搜索。如果资源标签值value是以&amp;ast;开头时，则按照&amp;ast;后面的值全模糊匹配。  默认值为空。
        :type tags: str
        :param name: Zone名称。  搜索模式默认为模糊搜索。
        :type name: str
        :param id: Zone ID。
        :type id: str
        :param status: 资源状态。
        :type status: str
        :param search_mode: 查询条件搜索模式。  取值范围：  like：模糊搜索 equal：精确搜索
        :type search_mode: str
        :param sort_key: 查询结果中zone列表的排序字段。  取值范围为：  name：域名 created_at：创建时间 updated_at：更新时间 默认值为空，表示不排序。
        :type sort_key: str
        :param sort_dir: 查询结果中zone列表的排序方式。  取值范围：  desc：降序排序 asc：升序排序 默认值为空，表示不排序。
        :type sort_dir: str
        :param enterprise_project_id: 域名关联的企业项目ID，长度不超过36个字符。
        :type enterprise_project_id: str
        """
        
        

        self._type = None
        self._limit = None
        self._marker = None
        self._offset = None
        self._tags = None
        self._name = None
        self._id = None
        self._status = None
        self._search_mode = None
        self._sort_key = None
        self._sort_dir = None
        self._enterprise_project_id = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if limit is not None:
            self.limit = limit
        if marker is not None:
            self.marker = marker
        if offset is not None:
            self.offset = offset
        if tags is not None:
            self.tags = tags
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        if search_mode is not None:
            self.search_mode = search_mode
        if sort_key is not None:
            self.sort_key = sort_key
        if sort_dir is not None:
            self.sort_dir = sort_dir
        if enterprise_project_id is not None:
            self.enterprise_project_id = enterprise_project_id

    @property
    def type(self):
        """Gets the type of this ListPublicZonesRequest.

        待查询的zone的类型。  取值范围：public 默认值为空。

        :return: The type of this ListPublicZonesRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ListPublicZonesRequest.

        待查询的zone的类型。  取值范围：public 默认值为空。

        :param type: The type of this ListPublicZonesRequest.
        :type type: str
        """
        self._type = type

    @property
    def limit(self):
        """Gets the limit of this ListPublicZonesRequest.

        每页返回的资源个数。  取值范围：0~500  取值一般为10，20，50。默认值为500。

        :return: The limit of this ListPublicZonesRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListPublicZonesRequest.

        每页返回的资源个数。  取值范围：0~500  取值一般为10，20，50。默认值为500。

        :param limit: The limit of this ListPublicZonesRequest.
        :type limit: int
        """
        self._limit = limit

    @property
    def marker(self):
        """Gets the marker of this ListPublicZonesRequest.

        分页查询起始的资源ID，为空时为查询第一页。  默认值为空。

        :return: The marker of this ListPublicZonesRequest.
        :rtype: str
        """
        return self._marker

    @marker.setter
    def marker(self, marker):
        """Sets the marker of this ListPublicZonesRequest.

        分页查询起始的资源ID，为空时为查询第一页。  默认值为空。

        :param marker: The marker of this ListPublicZonesRequest.
        :type marker: str
        """
        self._marker = marker

    @property
    def offset(self):
        """Gets the offset of this ListPublicZonesRequest.

        分页查询起始偏移量，表示从偏移量的下一个资源开始查询。  取值范围：0~2147483647  默认值为0。  当前设置marker不为空时，以marker为分页起始标识。

        :return: The offset of this ListPublicZonesRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListPublicZonesRequest.

        分页查询起始偏移量，表示从偏移量的下一个资源开始查询。  取值范围：0~2147483647  默认值为0。  当前设置marker不为空时，以marker为分页起始标识。

        :param offset: The offset of this ListPublicZonesRequest.
        :type offset: int
        """
        self._offset = offset

    @property
    def tags(self):
        """Gets the tags of this ListPublicZonesRequest.

        资源标签。  取值格式：key1,value1|key2,value2  多个标签之间用\"|\"分开，每个标签的键值用英文逗号\",\"相隔。  多个标签之间为“与”的关系。  关于资源标签，请参见添加资源标签。  搜索模式为精确搜索。如果资源标签值value是以&ast;开头时，则按照&ast;后面的值全模糊匹配。  默认值为空。

        :return: The tags of this ListPublicZonesRequest.
        :rtype: str
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ListPublicZonesRequest.

        资源标签。  取值格式：key1,value1|key2,value2  多个标签之间用\"|\"分开，每个标签的键值用英文逗号\",\"相隔。  多个标签之间为“与”的关系。  关于资源标签，请参见添加资源标签。  搜索模式为精确搜索。如果资源标签值value是以&ast;开头时，则按照&ast;后面的值全模糊匹配。  默认值为空。

        :param tags: The tags of this ListPublicZonesRequest.
        :type tags: str
        """
        self._tags = tags

    @property
    def name(self):
        """Gets the name of this ListPublicZonesRequest.

        Zone名称。  搜索模式默认为模糊搜索。

        :return: The name of this ListPublicZonesRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ListPublicZonesRequest.

        Zone名称。  搜索模式默认为模糊搜索。

        :param name: The name of this ListPublicZonesRequest.
        :type name: str
        """
        self._name = name

    @property
    def id(self):
        """Gets the id of this ListPublicZonesRequest.

        Zone ID。

        :return: The id of this ListPublicZonesRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ListPublicZonesRequest.

        Zone ID。

        :param id: The id of this ListPublicZonesRequest.
        :type id: str
        """
        self._id = id

    @property
    def status(self):
        """Gets the status of this ListPublicZonesRequest.

        资源状态。

        :return: The status of this ListPublicZonesRequest.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ListPublicZonesRequest.

        资源状态。

        :param status: The status of this ListPublicZonesRequest.
        :type status: str
        """
        self._status = status

    @property
    def search_mode(self):
        """Gets the search_mode of this ListPublicZonesRequest.

        查询条件搜索模式。  取值范围：  like：模糊搜索 equal：精确搜索

        :return: The search_mode of this ListPublicZonesRequest.
        :rtype: str
        """
        return self._search_mode

    @search_mode.setter
    def search_mode(self, search_mode):
        """Sets the search_mode of this ListPublicZonesRequest.

        查询条件搜索模式。  取值范围：  like：模糊搜索 equal：精确搜索

        :param search_mode: The search_mode of this ListPublicZonesRequest.
        :type search_mode: str
        """
        self._search_mode = search_mode

    @property
    def sort_key(self):
        """Gets the sort_key of this ListPublicZonesRequest.

        查询结果中zone列表的排序字段。  取值范围为：  name：域名 created_at：创建时间 updated_at：更新时间 默认值为空，表示不排序。

        :return: The sort_key of this ListPublicZonesRequest.
        :rtype: str
        """
        return self._sort_key

    @sort_key.setter
    def sort_key(self, sort_key):
        """Sets the sort_key of this ListPublicZonesRequest.

        查询结果中zone列表的排序字段。  取值范围为：  name：域名 created_at：创建时间 updated_at：更新时间 默认值为空，表示不排序。

        :param sort_key: The sort_key of this ListPublicZonesRequest.
        :type sort_key: str
        """
        self._sort_key = sort_key

    @property
    def sort_dir(self):
        """Gets the sort_dir of this ListPublicZonesRequest.

        查询结果中zone列表的排序方式。  取值范围：  desc：降序排序 asc：升序排序 默认值为空，表示不排序。

        :return: The sort_dir of this ListPublicZonesRequest.
        :rtype: str
        """
        return self._sort_dir

    @sort_dir.setter
    def sort_dir(self, sort_dir):
        """Sets the sort_dir of this ListPublicZonesRequest.

        查询结果中zone列表的排序方式。  取值范围：  desc：降序排序 asc：升序排序 默认值为空，表示不排序。

        :param sort_dir: The sort_dir of this ListPublicZonesRequest.
        :type sort_dir: str
        """
        self._sort_dir = sort_dir

    @property
    def enterprise_project_id(self):
        """Gets the enterprise_project_id of this ListPublicZonesRequest.

        域名关联的企业项目ID，长度不超过36个字符。

        :return: The enterprise_project_id of this ListPublicZonesRequest.
        :rtype: str
        """
        return self._enterprise_project_id

    @enterprise_project_id.setter
    def enterprise_project_id(self, enterprise_project_id):
        """Sets the enterprise_project_id of this ListPublicZonesRequest.

        域名关联的企业项目ID，长度不超过36个字符。

        :param enterprise_project_id: The enterprise_project_id of this ListPublicZonesRequest.
        :type enterprise_project_id: str
        """
        self._enterprise_project_id = enterprise_project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListPublicZonesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
